@@ -185,6 +185,7 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
         calc_gas_from_power=False,
         ambient_temperature=282.5,
         use_storage=False,
+        coords=None,
         **kwargs,
     ):
 
@@ -205,6 +206,7 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
             **kwargs,
         )
 
+        self.coords = coords
         self.name = name
         self.__load_regulation_multiplier = 1
         self.__heat_regulation_multiplier = initial_heat_regulation
@@ -538,6 +540,7 @@ class RegulatedG2PControlMultiEnergy(G2PControlMultiEnergy):
         level=0,
         drop_same_existing_ctrl=False,
         initial_run=True,
+        coords=None,
         **kwargs,
     ):
         super().__init__(
@@ -556,6 +559,7 @@ class RegulatedG2PControlMultiEnergy(G2PControlMultiEnergy):
             **kwargs,
         )
 
+        self.coords = coords
         self.__load_regulation_multiplier = 1
         self.name = name
         self.power_gen = 0
@@ -739,6 +743,7 @@ class RegulatedP2GControlMultiEnergy(P2GControlMultiEnergy):
         level=0,
         drop_same_existing_ctrl=False,
         initial_run=True,
+        coords=None,
         **kwargs,
     ):
 
@@ -757,6 +762,7 @@ class RegulatedP2GControlMultiEnergy(P2GControlMultiEnergy):
             **kwargs,
         )
 
+        self.coords = coords
         self.__load_regulation_multiplier = 1
         self.name = name
         self._desync = desync_mode
@@ -899,6 +905,7 @@ class RegulatedP2HControlMultiEnergy(Controller):
         level=0,
         drop_same_existing_ctrl=False,
         initial_run=True,
+        coords=None,
         **kwargs,
     ):
 
@@ -912,6 +919,7 @@ class RegulatedP2HControlMultiEnergy(Controller):
             **kwargs,
         )
 
+        self.coords = coords
         self.name = name
         self.__load_regulation_multiplier = 1
         self.name_net_heat = name_net_heat
