@@ -38,6 +38,7 @@ from peext.edge import (
     PipeEdge,
     SwitchEdge,
     TrafoEdge,
+    PumpEdge,
 )
 
 import pandapower as ppower
@@ -627,6 +628,15 @@ def from_panda_multinet(multinet):
                     HEAT_NET,
                 )
             )
+        if "pump" in heat_net:
+            for i in heat_net.pump.index:
+                edges[HEAT_NET].append(
+                    index_edge_by_eid(
+                        PumpEdge(i, heat_net, history_container=history_container),
+                        me_edges_index,
+                        HEAT_NET,
+                    )
+                )
         if "circ_pump_pressure" in heat_net:
             for i in heat_net.circ_pump_pressure.index:
                 edges[HEAT_NET].append(
