@@ -24,7 +24,7 @@ from peext.controller import (
 )
 
 REF_BAR = 60
-REF_TEMP = 290
+REF_TEMP = 359.5
 
 
 def create_small_test_multinet():
@@ -1433,7 +1433,9 @@ def create_gas_net_for_power(power_net, gas_deployment_rate, source_sink_ratio=0
     bus_index_to_junction_index = {}
     for i in power_net.bus.index:
         bus_coords = (power_net.bus_geodata["x"][i], power_net.bus_geodata["y"][i])
-        junc_id = ppipes.create_junction(net_gas, pn_bar=REF_BAR, tfluid_k=REF_TEMP, geodata=bus_coords)
+        junc_id = ppipes.create_junction(
+            net_gas, pn_bar=REF_BAR, tfluid_k=REF_TEMP, geodata=bus_coords
+        )
         bus_index_to_junction_index[i] = junc_id
 
     for i, from_bus, to_bus in zip(
@@ -1517,9 +1519,8 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
             from_junction=bus_index_to_junction_index[from_bus],
             to_junction=bus_index_to_junction_index[to_bus],
             length_km=0.01,
-            diameter_m=0.075,
-            k_mm=0.025,
-            alpha_w_per_m2k=100,
+            diameter_m=0.75,
+            alpha_w_per_m2k=2.4 * 10**-5,
             sections=1,
         )
         ppipes.create_pipe_from_parameters(
@@ -1531,9 +1532,8 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
                 to_bus + start_return_net_id_junctions
             ],
             length_km=0.01,
-            diameter_m=0.075,
-            k_mm=0.025,
-            alpha_w_per_m2k=100,
+            diameter_m=0.75,
+            alpha_w_per_m2k=2.4 * 10**-5,
             sections=1,
         )
 
@@ -1543,15 +1543,23 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
         power_net.line["from_bus"],
         power_net.line["to_bus"],
     ):
+        bus_coords = (
+            power_net.bus_geodata["x"][from_bus],
+            power_net.bus_geodata["y"][from_bus],
+        )
+        v_feed = ppipes.create_junction(
+            net_heat, pn_bar=REF_BAR, tfluid_k=REF_TEMP, geodata=bus_coords
+        )
+        ppipes.create_pump(
+            net_heat, bus_index_to_junction_index[from_bus], v_feed, std_type="P1"
+        )
         ppipes.create_pipe_from_parameters(
             net_heat,
-            from_junction=bus_index_to_junction_index[from_bus],
+            from_junction=v_feed,
             to_junction=bus_index_to_junction_index[to_bus],
             length_km=length * (random.random() / 4 + (7 / 8)),
-            diameter_m=0.075,
-            k_mm=0.025,
-            alpha_w_per_m2k=100,
-            sections=5,
+            diameter_m=0.75,
+            alpha_w_per_m2k=2.4 * 10**-5,
         )
         ppipes.create_pipe_from_parameters(
             net_heat,
@@ -1562,10 +1570,8 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
                 to_bus + start_return_net_id_junctions
             ],
             length_km=length * (random.random() / 4 + (7 / 8)),
-            diameter_m=0.075,
-            k_mm=0.025,
-            alpha_w_per_m2k=100,
-            sections=5,
+            diameter_m=0.75,
+            alpha_w_per_m2k=2.4 * 10**-5,
         )
 
     for i in power_net.bus.index:
@@ -1577,8 +1583,8 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
                 to_junction=bus_index_to_junction_index[
                     i + start_return_net_id_junctions
                 ],
-                diameter_m=0.075,
-                qext_w=-0.1,
+                diameter_m=0.75,
+                qext_w=10**6 * (random.random() - 0.5),
             )
 
     ppipes.create_ext_grid(
